# springtownai-rag.py
import boto3

class springtownai-rag:
    def __init__(self):
        self.s3 = boto3.client('s3')

    def download_file(self, bucket_name, key, download_path):
        """
        Download a file from S3.

        :param bucket_name: The name of the S3 bucket.
        :param key: The object key in the S3 bucket (file path in S3).
        :param download_path: The local path to save the downloaded file.
        """
        self.s3.download_file(bucket_name, key, download_path)




from setuptools import setup, find_packages

setup(
    name="springtownai-rag",
    version="0.1",
    packages=find_packages(),
    install_requires=[
        "boto3",
    ],
    author="Your Name",
    author_email="dhruv.307@gmail.com",
    description="A simple S3 file downloader",
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    url="https://github.com/dhruvgm/springtownai-rag",  # If you have a repo for this package
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)

